@@ -5,4 +5,4 @@ cd ../../Source
 make -f macosx.mak clean all
 cd $STARTDIR
 
-/usr/bin/python make_pkg.py
+${PYTHON} make_pkg.py
