@@ -3,6 +3,8 @@
 #
 import bundlebuilder
 import sys
+import pysvn
+import shutil
 
 # make sure that we get 2.6 and not an earlier version
 if not hasattr(sys, 'frozen'):
@@ -13,6 +15,25 @@ import wx
 import os
 import traceback
 
+
+def findDylibs( image, dylib_list, depth=0 ):
+    cmd = 'otool -L "%s" >/tmp/pysvn_otool.tmp' % image
+    #print 'Debug: cmd %r' % cmd
+    os.system( cmd )
+    # always skip the first line that lists the image being dumped
+    for line in file( '/tmp/pysvn_otool.tmp' ).readlines()[1:]:
+        line = line.strip()
+        #print 'Debug: line %r' % line
+        if( line.startswith( '/' )
+        and not line.startswith( '/usr/lib' )
+        and not line.startswith( '/System' ) ):
+            libpath = line.split()[0]
+            if libpath not in dylib_list:
+                print 'Info: ',depth,' Need lib',libpath,'for',image
+                dylib_list.append( libpath )
+                findDylibs( libpath, dylib_list, depth+1 )
+        
+
 try:
     # workbench sources
     sys.path.append( '../../Source' )
@@ -60,26 +81,19 @@ try:
         if not lib_found:
             raise ValueError( 'Cannot find lib %s' % libname )
 
-    # add in libs from Fink
-    if os.path.exists( '/sw' ):
-        for libname in [
-                "/sw/lib/libintl.3.dylib",
-                "/sw/lib/libiconv.2.dylib",
-                ]:
-            print 'Info: Manually adding lib %s' % libname
-            myapp.libs.append( libname )
-    if os.path.exists( '/opt/local' ):
-        for libname in [
-                "/opt/local/lib/libapr-1.0.dylib",
-                "/opt/local/lib/libz.1.dylib",
-                ]:
-            print 'Info: Manually adding lib %s' % libname
-            myapp.libs.append( libname )
+    print 'Info: Finding dylibs used by pysvn'
+    findDylibs( pysvn._pysvn.__file__, myapp.libs )
 
     # Here we build the app!
     myapp.setup()
     myapp.build()
 
+    # remove unnecessary files
+    os.system( 'pwd' )
+    doc_path = os.path.join( sys.argv[1],
+        'WorkBench.app/Contents/Frameworks/Python.framework/Versions/2.5/Resources/English.lproj/Documentation' )
+    print doc_path
+    shutil.rmtree( doc_path )
 except:
     traceback.print_exc( file=sys.stderr )
     sys.exit( 1 )
