@@ -69,10 +69,16 @@ class WbApp(wx.App):
 
         self.setupLogging()
 
-        self.prefs = wb_preferences.Preferences(
-                self,
-                wb_platform_specific.getPreferencesFilename(),
-                wb_platform_specific.getOldPreferencesFilename() )
+        if '--test' in args:
+            self.prefs = wb_preferences.Preferences(
+                    self,
+                    wb_platform_specific.getPreferencesFilename() + '.test',
+                    wb_platform_specific.getOldPreferencesFilename() + '.test' )
+        else:
+            self.prefs = wb_preferences.Preferences(
+                    self,
+                    wb_platform_specific.getPreferencesFilename(),
+                    wb_platform_specific.getOldPreferencesFilename() )
 
         self.lock_ui = 0
         self.need_activate_app_action = False
