@@ -47,7 +47,7 @@ class BackgroundThread(threading.Thread):
         self.queued_work_semaphore.release()
 
     def shutdown( self ):
-        self.addWork( self._shutdown )
+        self.addWork( self.__shutdown )
 
-    def _shutdown( self ):
+    def __shutdown( self ):
         self.running = 0
