@@ -37,8 +37,6 @@ class BookmarkManageDialog(wx.Dialog):
 
         self.bookmark_prefs = bookmark_prefs
 
-        self.selection = None
-
         self.initControls()
 
     def initControls( self ):
@@ -65,7 +63,7 @@ class BookmarkManageDialog(wx.Dialog):
 
         self.bookmark_list_ctrl.SetItemCount( len( self.all_bookmark_props ) )
 
-        self.button_delete = wx.Button( self, wx.NewId(), " Delete Bookmark " )
+        self.button_delete = wx.Button( self, wx.NewId(), " Delete " )
         self.button_delete.Enable( False )
 
         self.button_props = wx.Button( self, wx.NewId(), " Properties " )
@@ -143,34 +141,53 @@ class BookmarkManageDialog(wx.Dialog):
         self.OnPropertiesBookmark( event )
 
     def OnSelectBookmark( self, event ):
-        self.selection = event.m_itemIndex
         self.button_delete.Enable( True )
         self.button_props.Enable( True )
 
     def OnDeselectBookmark( self, event ):
-        self.selection = None
-        self.button_delete.Enable( False )
-        self.button_props.Enable( False )
+        if self.bookmark_list_ctrl.GetNextSelected(-1) < 0:
+            self.button_delete.Enable( False )
+            self.button_props.Enable( False )
 
     def OnDeleteBookmark( self, event ):
-        self.bookmark_deleted_list.append( self.all_bookmark_props.pop( self.selection ) )
+        # delete all selected bookmarks.
+        bookmark_index = -1
+        selected_bookmarks = []
+        while True:
+            bookmark_index = self.bookmark_list_ctrl.GetNextSelected( bookmark_index )
+            if bookmark_index < 0:
+                break
+            selected_bookmarks.append( bookmark_index )
+        for bookmark_index in reversed( selected_bookmarks ):
+            self.bookmark_deleted_list.append( self.all_bookmark_props.pop( bookmark_index ) )
 
-        self.bookmark_list_ctrl.SetItemCount( len(self.all_bookmark_props ) )
-        self.bookmark_list_ctrl.RefreshItems( 0, len(self.all_bookmark_props )-1 )
-
-        self.button_delete.Enable( False )
-        self.button_props.Enable( False )
+        # if there is a bookmark left after the last deletion,
+        # select it, so pressing delete multiple times works.
+        if len( self.all_bookmark_props ) > 0:
+            self.bookmark_list_ctrl.Select( bookmark_index )
+            self.bookmark_list_ctrl.SetItemCount( len( self.all_bookmark_props ) )
+            self.bookmark_list_ctrl.RefreshItems( 0, len( self.all_bookmark_props )-1 )
+        else:
+            self.button_delete.Enable( False )
+            self.button_props.Enable( False )
+            self.bookmark_list_ctrl.SetItemCount( 0 )
 
     def OnPropertiesBookmark( self, event ):
-        props = self.all_bookmark_props[ self.selection ]
-        dialog = BookmarkPropertiesDialog( self, self.app, props )
+        refresh_list = False
+        bookmark_index = -1
+        while True:
+            bookmark_index = self.bookmark_list_ctrl.GetNextSelected( bookmark_index )
+            if bookmark_index < 0:
+                break
+            dialog = BookmarkPropertiesDialog( self, self.app, self.all_bookmark_props[ bookmark_index ] )
 
-        rc = dialog.ShowModal()
-        if rc != wx.ID_OK:
-            return
+            rc = dialog.ShowModal()
+            if rc == wx.ID_OK:
+                refresh_list = True
 
-        self.sortBookmarks()
-        self.bookmark_list_ctrl.RefreshItems( 0, len(self.all_bookmark_props )-1 )
+        if refresh_list:
+            self.sortBookmarks()
+            self.bookmark_list_ctrl.RefreshItems( 0, len( self.all_bookmark_props )-1 )
 
     def setPreferences( self ):
         for props in self.getDeletedBookmarkList():
