@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -522,3 +522,89 @@ class NewFile(wx.Dialog):
             return self.template_file_list[ index ] + self.template_suffix
         else:
             return None
+
+class CopyUrl(wx.Dialog):
+    def __init__( self, parent, title, copy_from_url, copy_to_url ):
+        wx.Dialog.__init__( self, parent, -1, '%s %s' % (title, copy_from_url) )
+
+        self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
+        self.g_sizer.AddGrowableCol( 1 )
+
+        self.copyurl_border = wx.StaticBox( self, -1, title )
+        self.copyurl_box = wx.StaticBoxSizer( self.copyurl_border, wx.VERTICAL )
+        self.copyurl_box.Add( self.g_sizer, 0, wx.EXPAND )
+
+        self.copy_from_label = wx.StaticText( self, -1, 'Copy From:' )
+        self.copy_from_value = wx.StaticText( self, -1, copy_from_url )
+
+        self.copy_to_label = wx.StaticText( self, -1, 'Copy To:' )
+        self.copy_to_root = wx.StaticText( self, -1, copy_to_url + '/' )
+        self.copy_to_leaf = wx.TextCtrl( self, -1, '' )
+
+        self.h_sizer_copy_to = wx.BoxSizer( wx.HORIZONTAL )
+        self.h_sizer_copy_to.Add( self.copy_to_root, 0, wx.EXPAND|wx.EAST, 15 )
+        self.h_sizer_copy_to.Add( self.copy_to_leaf, 0, wx.EXPAND|wx.EAST, 2 )
+
+        self.g_sizer.Add( self.copy_from_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
+        self.g_sizer.Add( self.copy_from_value, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.g_sizer.Add( self.copy_to_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
+        self.g_sizer.Add( self.h_sizer_copy_to, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.label_ctrl = wx.StaticText( self, -1, 'Log message', style=wx.ALIGN_LEFT )
+        self.log_message_ctrl = wx.TextCtrl( self, -1, style=wx.TE_MULTILINE )
+
+        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok.SetDefault()
+        self.button_ok.Enable( False )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+
+        self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
+        self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
+        self.h_sizer_buttons.Add( self.button_ok, 0, wx.EXPAND|wx.EAST, 15 )
+        self.h_sizer_buttons.Add( self.button_cancel, 0, wx.EXPAND|wx.EAST, 2 )
+
+        self.v_sizer = wx.BoxSizer( wx.VERTICAL )
+        self.v_sizer.Add( self.copyurl_box, 0, wx.EXPAND|wx.ALL, 5 )
+        self.v_sizer.Add( self.label_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+        self.v_sizer.Add( self.log_message_ctrl, 1, wx.EXPAND|wx.ALL, 5 )
+
+        self.v_sizer.Add( self.h_sizer_buttons, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.SetAutoLayout( True )
+        self.SetSizer( self.v_sizer )
+        self.v_sizer.Fit( self )
+        self.Layout()
+
+        self.CentreOnParent()
+
+        wx.EVT_TEXT( self, self.log_message_ctrl.GetId(), self.OnLogMessageChanged )
+        wx.EVT_BUTTON( self, wx.ID_OK, self.OnOk )
+        wx.EVT_BUTTON( self, wx.ID_CANCEL, self.OnCancel )
+
+        self.copy_to_label.SetFocus()
+
+    def OnLogMessageChanged( self, event ):
+        self.button_ok.Enable(
+                len( self.log_message_ctrl.GetValue().strip() ) > 0
+            and len( self.copy_to_leaf.GetValue().strip() ) > 0 )
+
+    def OnOk( self, event ):
+        self.EndModal( wx.ID_OK )
+
+    def OnCancel( self, event ):
+        self.EndModal( wx.ID_CANCEL )
+
+    def getCopyToLeaf( self ):
+        return self.copy_to_leaf.GetValue().strip()
+
+    def getLogMessage( self ):
+        return self.log_message_ctrl.GetValue()
+
+class CreateTag(CopyUrl):
+    def __init__( self, parent, copy_from_url, copy_to_url ):
+        CopyUrl.__init__( self, parent, 'Create Tag', copy_from_url, copy_to_url )
+
+class CreateBranch(CopyUrl):
+    def __init__( self, parent, copy_from_url, copy_to_url ):
+        CopyUrl.__init__( self, parent, 'Create Branch', copy_from_url, copy_to_url )
