@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -223,12 +223,15 @@ class DiffFrame(wx.Frame):
         self.panel_right.ed.ToggleViewWhiteSpace()
 
     def OnToolExpandFolds( self, event ):
-        self.panel_left.ed.ShowAllFolds( True )
-        self.panel_right.ed.ShowAllFolds( True )
+        self.showAllFolds( True )
 
     def OnToolCollapseFolds( self, event ):
-        self.panel_left.ed.ShowAllFolds( False )
-        self.panel_right.ed.ShowAllFolds( False )
+        self.showAllFolds( False )
+
+    def showAllFolds( self, show ):
+        self.panel_left.ed.ShowAllFolds( show )
+        self.panel_right.ed.ShowAllFolds( show )
+
 
 #----------------------------------------------------------------------
 
