@@ -29,7 +29,10 @@ import wb_preferences
 class WbDiffApp:
     def __init__( self ):
         self.log = self
-        self.prefs = wb_preferences.Preferences( self )
+        self.prefs = wb_preferences.Preferences(
+                self,
+                wb_platform_specific.getPreferencesFilename(),
+                wb_platform_specific.getOldPreferencesFilename() )
 
     def info( self, *arg ):
         pass
