@@ -44,7 +44,7 @@ class TryWrapper:
         try:
             result = self.function( *params, **keywords )
             return result
-        except:
+        except Exception:
             self.log.exception( 'TryWrapper<%s.%s>\n' %
                 (self.function.__module__, self.function.__name__ ) )
 
