@@ -109,6 +109,9 @@ class WbFrame(wx.Frame):
         self.menu_actions.Append( wb_ids.id_SP_Revert, 'Revert...', 'Revert' )
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Cleanup, 'Clean up', 'Clean up working copy' )
+        self.menu_actions.AppendSeparator()
+        self.menu_actions.Append( wb_ids.id_SP_CreateTag, 'Create Tag...', 'Create Tag' )
+        self.menu_actions.Append( wb_ids.id_SP_CreateBranch, 'Create Branch...', 'Create Branch' )
 
         self.menu_reports = wx.Menu()
         self.menu_reports.Append( wb_ids.id_SP_Report_LocksWc, 'Working copy Locks...', 'Locks held in Working Copy' )
@@ -335,6 +338,10 @@ class WbFrame(wx.Frame):
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Checkout, self.app.eventWrapper( self.OnUpdateUiSpCheckout ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Cleanup, self.app.eventWrapper( self.OnSpCleanup ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Cleanup, self.app.eventWrapper( self.OnUpdateUiSpCleanup ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_CreateTag, self.app.eventWrapper( self.OnSpCreateTag ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CreateTag, self.app.eventWrapper( self.OnUpdateUiSpCreateTag ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_CreateBranch, self.app.eventWrapper( self.OnSpCreateBranch ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CreateBranch, self.app.eventWrapper( self.OnUpdateUiSpCreateBranch ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Delete, self.app.eventWrapper( self.OnSpDelete ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Delete, self.app.eventWrapper( self.OnUpdateUiSpDelete ) )
         wx.EVT_MENU( self, wb_ids.id_SP_DiffMineNew, self.app.eventWrapper( self.OnSpDiffMineNew ) )
@@ -822,6 +829,20 @@ class WbFrame(wx.Frame):
         self.getUpdateUiState()
         event.Enable( self.ui_state_focus.file_exists and self.ui_state_focus.versioned )
 
+    def OnSpCreateTag( self, event ):
+        return self.Sp_Dispatch( 'OnSpCreateTag' )
+
+    def OnUpdateUiSpCreateTag( self, event ):
+        self.getUpdateUiState()
+        event.Enable( self.ui_state_tree.file_exists and self.ui_state_tree.versioned )
+
+    def OnSpCreateBranch( self, event ):
+        return self.Sp_Dispatch( 'OnSpCreateBranch' )
+
+    def OnUpdateUiSpCreateBranch( self, event ):
+        self.getUpdateUiState()
+        event.Enable( self.ui_state_tree.file_exists and self.ui_state_tree.versioned )
+
     def OnSpDelete( self, event ):
         return self.Sp_Dispatch( 'OnSpDelete' )
 
