@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -70,10 +70,12 @@ id_SP_Resolved = wx.NewId()
 id_SP_Revert = wx.NewId()
 id_SP_Unlock = wx.NewId()
 id_SP_Update = wx.NewId()
+id_SP_CreateTag = wx.NewId()
+id_SP_CreateBranch = wx.NewId()
 
 id_SP_Report_Updates = wx.NewId()
 id_SP_Report_LocksWc = wx.NewId()
-id_SP_Report_LocksRepos = wx.NewId()#1
+id_SP_Report_LocksRepos = wx.NewId()
 id_SP_Report_BranchChanges = wx.NewId()
 
 id_NextControl = wx.NewId()
