@@ -19,6 +19,11 @@ class WbListPanel(wb_list_panel_common.WbListPanelCommon):
     def __init__( self, app, frame, parent ):
         wb_list_panel_common.WbListPanelCommon.__init__( self, app, frame, parent )
 
+        wx.EVT_MENU( self, wb_ids.id_NextControl, self.app.eventWrapper( self.OnNextControl ) )
+
+    def OnNextControl( self, event ):
+        self.frame.tree_panel.SetFocus()
+
     def __repr__( self ):
         return '<WbListPanel %r>' % self.list_handler
 
@@ -39,7 +44,7 @@ class WbListPanel(wb_list_panel_common.WbListPanelCommon):
                 (wx.ACCEL_ALT, ord('U'), wb_ids.id_SP_Update),
                 (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
                 (wx.ACCEL_ALT, wx.WXK_BACK, wb_ids.id_SP_Delete),
-                (wx.ACCEL_NORMAL, wx.WXK_RETURN, wb_ids.id_Return_Hotkey),
+                (wx.ACCEL_NORMAL, wx.WXK_TAB, wb_ids.id_NextControl),
                 (wx.ACCEL_ALT, ord('O'), wb_ids.id_Shell_Open),
                 ]
         elif wx.Platform == '__WXMSW__':
@@ -57,7 +62,7 @@ class WbListPanel(wb_list_panel_common.WbListPanelCommon):
                 (wx.ACCEL_CTRL, ord('R'), wb_ids.id_SP_Revert),
                 (wx.ACCEL_CTRL, ord('U'), wb_ids.id_SP_Update),
                 (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
-                (wx.ACCEL_NORMAL, wx.WXK_RETURN, wb_ids.id_Return_Hotkey),
+                (wx.ACCEL_NORMAL, wx.WXK_TAB, wb_ids.id_NextControl),
                 (wx.ACCEL_CTRL, ord('O'), wb_ids.id_Shell_Open),
                 ]
         else:
@@ -76,6 +81,7 @@ class WbListPanel(wb_list_panel_common.WbListPanelCommon):
                 (wx.ACCEL_CTRL, ord('R'), wb_ids.id_SP_Revert),
                 (wx.ACCEL_CTRL, ord('U'), wb_ids.id_SP_Update),
                 (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
-                (wx.ACCEL_NORMAL, wx.WXK_RETURN, wb_ids.id_Return_Hotkey),
+                (wx.ACCEL_NORMAL, wx.WXK_TAB, wb_ids.id_NextControl),
+                (wx.ACCEL_CTRL, ord('O'), wb_ids.id_Shell_Open),
                 ]
         return acc_init
