@@ -44,7 +44,10 @@ class ListSortData:
 
 
 class ListItemState:
-    def __init__( self ):
+    def __init__( self, place_holder=False ):
+        # used to tell if the state reflects a items state or is just a place holder
+        self.place_holder = place_holder
+
         self.modified = False
         self.versioned = False
         self.new_versioned = False
@@ -53,6 +56,7 @@ class ListItemState:
         self.need_checkout = False
         self.conflict = False
         self.file_exists = False
+        self.is_folder = False
         self.is_project_parent = False
 
     def printState( self, title='' ):
@@ -83,7 +87,7 @@ class WbListCtrl(wx.ListCtrl):
 
 class WbListPanelCommon(wx.Panel):
     def __init__( self, app, frame, parent ):
-        wx.Panel.__init__(self, parent, -1)
+        wx.Panel.__init__( self, parent )
 
         self.app = app
         self.frame = frame
@@ -100,8 +104,21 @@ class WbListPanelCommon(wx.Panel):
         self.id_list = wx.NewId()
         self.list_ctrl = WbListCtrl( self, self.id_list )
 
+        if wb_config.focus_ring:
+            self.focus_ring_panel = wx.Panel( self )
+
+            box = wx.BoxSizer( wx.VERTICAL )
+            box.Add( self.list_ctrl, 1, wx.EXPAND|wx.ALL, 3)
+            self.focus_ring_panel.SetSizer( box )
+            
+            self.list_ctrl.Bind( wx.EVT_PAINT, self.OnPaint )
+
+            list_window = self.focus_ring_panel
+        else:
+            list_window = self.list_ctrl
+
         self.v_sizer.Add( self.header_panel, 0, wx.EXPAND|wx.ALL, 0 )
-        self.v_sizer.Add( self.list_ctrl, 1, wx.EXPAND|wx.ALL, 0 )
+        self.v_sizer.Add( list_window, 1, wx.EXPAND|wx.ALL, 0 )
 
         acc_tab = wx.AcceleratorTable( self.getAcceleratorTableInit() )
         self.list_ctrl.SetAcceleratorTable( acc_tab )
@@ -140,15 +157,45 @@ class WbListPanelCommon(wx.Panel):
     def __repr__( self ):
         return '<WbListPanelCommon %r>' % self.list_handler
 
+    def OnPaint( self, event ):
+        event.Skip()
+        return
+
+        dc = wx.PaintDC( self )
+        #dc.Clear()
+        w, h = self.GetSize()
+        if self.FindFocus() == self.list_ctrl:
+            print 'list focus'
+            dc.SetPen( wx.Pen( "red", 1 ) )
+            dc.DrawRectangle( 0, 0, w, h )
+        else:
+            dc.SetPen( wx.Pen( "green", 1 ) )
+            dc.DrawRectangle( 0, 0, w, h )
+            print 'list unfocus'
+
+        event.Skip()
+
     def addToSizer( self, v_sizer ):
         pass
 
+    def setFocusFilter( self ):
+        self.header_panel.setFocusFilter()
+
     def OnSetFocus( self, event ):
-        self.frame.setEventHandler( self )
+        #self.frame.setEventHandler( self )
+
+        if wb_config.focus_ring:
+            self.Refresh()
+
+        event.Skip()
 
     def OnKillFocus( self, event ):
         #self.frame.clearEventHandler()
-        pass
+
+        if wb_config.focus_ring:
+            self.Refresh()
+
+        event.Skip()
 
     def OnItemSelected( self, event ):
         self.frame.clearUpdateUiState()
@@ -405,7 +452,6 @@ class HeaderPanel(wx.Panel):
 
         self.app = app
 
-
         self.background_colour = wx.SystemSettings.GetColour( wx.SYS_COLOUR_3DFACE )
 
         self.v_sizer = wx.BoxSizer( wx.VERTICAL )
@@ -448,11 +494,23 @@ class HeaderPanel(wx.Panel):
         wx.EVT_TEXT( self, self.filter_text_ctrl.GetId(), self.OnFilterTextChanged )
         wx.EVT_CHOICE( self, self.filter_choice_ctrl.GetId(), self.OnFilterTypeChanged )
 
+        wx.EVT_KEY_DOWN( self, self.OnKeyDown )
+
         self.SetAutoLayout( True )
         self.SetSizer( self.v_sizer )
         self.v_sizer.Fit( self )
         self.Layout()
 
+
+    def OnKeyDown( self, event ):
+        if event.GetKeyCode() == wx.WXK_TAB:
+            self.app.frame.list_panel.SetFocus()
+        else:
+            event.Skip()
+
+    def setFocusFilter( self ):
+        self.filter_text_ctrl.SetFocus()
+
     def setFilterChangedHandler( self, handler ):
         self.filter_changed_handler = handler
 
