@@ -106,6 +106,9 @@ import encodings
 import encodings.aliases
 import encodings.ascii
 import encodings.base64_codec
+import encodings.big5
+import encodings.big5hkscs
+import encodings.bz2_codec
 import encodings.charmap
 import encodings.cp037
 import encodings.cp1006
@@ -140,13 +143,32 @@ import encodings.cp866
 import encodings.cp869
 import encodings.cp874
 import encodings.cp875
-import encodings.hex_codec
-import encodings.idna
+import encodings.cp932
+import encodings.cp949
+import encodings.cp950
+import encodings.euc_jis_2004
+import encodings.euc_jisx0213
+import encodings.euc_jp
+import encodings.euc_kr
+import encodings.gb18030
+import encodings.gb2312
+import encodings.gbk
+import encodings.hp_roman8
+import encodings.hz
+import encodings.iso2022_jp
+import encodings.iso2022_jp_1
+import encodings.iso2022_jp_2
+import encodings.iso2022_jp_2004
+import encodings.iso2022_jp_3
+import encodings.iso2022_jp_ext
+import encodings.iso2022_kr
 import encodings.iso8859_1
 import encodings.iso8859_10
+import encodings.iso8859_11
 import encodings.iso8859_13
 import encodings.iso8859_14
 import encodings.iso8859_15
+import encodings.iso8859_16
 import encodings.iso8859_2
 import encodings.iso8859_3
 import encodings.iso8859_4
@@ -155,6 +177,7 @@ import encodings.iso8859_6
 import encodings.iso8859_7
 import encodings.iso8859_8
 import encodings.iso8859_9
+import encodings.johab
 import encodings.koi8_r
 import encodings.koi8_u
 import encodings.latin_1
@@ -164,13 +187,17 @@ import encodings.mac_iceland
 import encodings.mac_latin2
 import encodings.mac_roman
 import encodings.mac_turkish
-#import encodings.mbcs
 import encodings.palmos
+import encodings.ptcp154
 import encodings.punycode
 import encodings.quopri_codec
 import encodings.raw_unicode_escape
 import encodings.rot_13
+import encodings.shift_jis
+import encodings.shift_jis_2004
+import encodings.shift_jisx0213
 import encodings.string_escape
+import encodings.tis_620
 import encodings.undefined
 import encodings.unicode_escape
 import encodings.unicode_internal
@@ -182,6 +209,14 @@ import encodings.utf_8
 import encodings.uu_codec
 import encodings.zlib_codec
 
+if sys.version_info >= (2,5,0,'',0):
+    import encodings.mac_arabic
+    import encodings.mac_centeuro
+    import encodings.mac_croatian
+    import encodings.mac_farsi
+    import encodings.mac_romanian
+    import encodings.utf_8_sig
+
 # keep pychecker quite
 def __pychecker():
     return encodings.utf_8 and warnings
