@@ -21,6 +21,7 @@ import UserDict
 
 import xml.parsers.expat
 import xml.dom.minidom
+import xml.sax.saxutils
 
 import wx
 
@@ -59,6 +60,7 @@ class Preferences:
         self.pref_handlers['Editor'] = EditorPreferences( self.app )
         self.pref_handlers['Shell'] = ShellPreferences( self.app )
         self.pref_handlers['DiffTool'] = DiffToolPreferences( self.app )
+        self.pref_handlers['LogHistory'] = LogHistroyPreferences( self.app )
 
         # read preferences into the handlers
         self.readPreferences()
@@ -94,12 +96,24 @@ class Preferences:
                 self.pref_data.add_section( handler.section_name )
                 handler.writePreferences( self.pref_data )
 
-            f = file( self.pref_filename, 'w' )
+            # write the prefs so that a failure to write does not
+            # destroy the original
+            # also keep one backup copy
+            new_name = self.pref_filename + '.tmp'
+            old_name = self.pref_filename + '.old'
+
+            f = file( new_name, 'w' )
             self.pref_data.write( f )
             f.close()
+            if os.path.exists( self.pref_filename ):
+                if os.path.exists( old_name ): # os.rename does not delete automatically on Windows.
+                    os.remove( old_name )
+                os.rename( self.pref_filename, old_name )
+            os.rename( new_name, self.pref_filename )
+
             self.app.log.info( 'Wrote preferences to %s' % self.pref_filename )
 
-        except IOError, e:
+        except EnvironmentError, e:
             self.app.log.error( 'write preferences: %s' % e )
 
 class PreferenceData:
@@ -275,7 +289,8 @@ class PreferenceData:
                     self.__writeDictionary( f, item, indent + 4 )
                     f.write( '%*s</%s>\n' % (indent, '', key_name) )
             else:
-                f.write( '%*s<%s>%s</%s>\n' % (indent, '', key_name, unicode(value).encode('utf-8'), key_name) )
+                quoted_value = xml.sax.saxutils.escape( unicode( value ) ).encode('utf-8')
+                f.write( '%*s<%s>%s</%s>\n' % (indent, '', key_name, quoted_value, key_name) )
 
 class PreferenceSection:
     def __init__( self, section_name ):
@@ -729,6 +744,36 @@ class DiffToolPreferences(PreferenceSection):
         if self.shell_diff_tool_options != '':
             set_option.set( 'shell_diff_tool_options', self.shell_diff_tool_options )
 
+class LogHistroyPreferences(PreferenceSection):
+    def __init__( self, app ):
+        PreferenceSection.__init__( self, 'LogHistory' )
+        self.app = app
+
+        self.default_mode = 'show_all'
+        self.default_limit = 20
+        self.default_since_days_interval = 7
+        self.default_include_tags = False
+
+    def readPreferences( self, pref_data ):
+        get_option = GetOption( pref_data, self.section_name )
+
+        if get_option.has( 'default_mode' ):
+            self.default_mode = get_option.getstr( 'default_mode' )
+        if get_option.has( 'default_limit' ):
+            self.default_limit = get_option.getint( 'default_limit' )
+        if get_option.has( 'default_since_days_interval' ):
+            self.default_since_days_interval = get_option.getint( 'default_since_days_interval' )
+        if get_option.has( 'default_include_tags' ):
+            self.default_include_tags = get_option.getbool( 'default_include_tags' )
+
+    def writePreferences( self, pref_data ):
+        set_option = SetOption( pref_data, self.section_name )
+
+        set_option.set( 'default_mode', self.default_mode )
+        set_option.set( 'default_limit', self.default_limit )
+        set_option.set( 'default_since_days_interval', self.default_since_days_interval )
+        set_option.set( 'default_include_tags', self.default_include_tags )
+
 if __name__ == '__main__':
     class FakeApp:
         def __init__( self ):
