@@ -47,6 +47,7 @@ class PreferencesDialog( wx.Dialog ):
         self.pages.append( DiffToolPage( self.notebook, self.app ) )
         self.pages.append( ShellPage( self.notebook, self.app ) )
         self.pages.append( ListColumnsPage( self.notebook, self.app ) )
+        self.pages.append( LogHistoryPage( self.notebook, self.app ) )
         # may want view page for editing the control file
         #self.pages.append( ViewPage( self.notebook, self.app ) )
 
@@ -694,3 +695,81 @@ class ListColumnsPage(PagePanel):
             return False
 
         return True
+
+class LogHistoryPage(PagePanel):
+    def __init__( self, notebook, app ):
+        self.app = app
+        PagePanel.__init__( self, notebook, 'Log History' )
+
+    def initControls( self ):
+        p = self.app.prefs.getLogHistory()
+
+        self.mode_values = ['show_all', 'show_limit', 'show_since' ]
+        self.mode_choice_values = ['Show all entries', 'Show only', 'Show since']
+        self.mode_label = wx.StaticText( self, -1, 'Default mode: ', style=wx.ALIGN_RIGHT)
+        self.mode_ctrl = wx.Choice( self, -1, choices = self.mode_choice_values )
+        self.mode_ctrl.SetSelection( self.mode_values.index( p.default_mode ) )
+
+        self.limit_label = wx.StaticText( self, -1, 'Default limit: ', style=wx.ALIGN_RIGHT)
+        self.limit_ctrl = wx.TextCtrl( self, -1, str( p.default_limit ), wx.DefaultPosition, wx.Size(415, -1) )
+
+        self.since_label = wx.StaticText( self, -1, 'Default since interval (days): ', style=wx.ALIGN_RIGHT)
+        self.since_ctrl = wx.TextCtrl( self, -1, str( p.default_since_days_interval ), wx.DefaultPosition, wx.Size(415, -1) )
+
+        self.tags_label = wx.StaticText( self, -1, 'Default Include tags: ', style=wx.ALIGN_RIGHT)
+        self.tags_ctrl = wx.CheckBox( self, -1, 'Include tags in log history' )
+        self.tags_ctrl.SetValue( p.default_include_tags )
+
+        self.grid_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
+        self.grid_sizer.AddGrowableCol( 1 )
+
+        self.grid_sizer.Add( self.mode_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( self.mode_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.grid_sizer.Add( self.limit_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( self.limit_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.grid_sizer.Add( self.since_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( self.since_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.grid_sizer.Add( self.tags_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( self.tags_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
+
+        return self.grid_sizer
+
+    def savePreferences( self ):
+        p = self.app.prefs.getLogHistory()
+
+        p.default_mode = self.mode_values[ self.mode_ctrl.GetSelection() ]
+        p.default_limit = int( self.limit_ctrl.GetValue() )
+        p.default_since_days_interval = int( self.since_ctrl.GetValue() )
+        p.default_include_tags = self.tags_ctrl.GetValue()
+
+    def validate( self ):
+        try:
+            limit = int( self.limit_ctrl.GetValue() )
+            if limit < 1:
+                raise ValueError( 'out of range' )
+        except ValueError:
+            wx.MessageBox(
+                'Limit must be greater then 0',
+                'Warning',
+                wx.OK | wx.ICON_EXCLAMATION,
+                self )
+            return False
+
+        try:
+            since_days = int( self.since_ctrl.GetValue() )
+            if since_days < 1:
+                raise ValueError( 'out of range' )
+        except ValueError:
+            wx.MessageBox(
+                'Since days must be greater then 0',
+                'Warning',
+                wx.OK | wx.ICON_EXCLAMATION,
+                self )
+            return False
+
+        return True
