@@ -12,7 +12,9 @@
 '''
 
 import wx
+import wx.stc
 
+import wb_config
 import wb_diff_frame
 
 class ShowDiffFrame(wx.Frame):
@@ -31,11 +33,14 @@ class ShowDiffFrame(wx.Frame):
                 diff_prefs.frame_size,
                 wx.DEFAULT_FRAME_STYLE|extra_style )
 
-        text_control = wx.TextCtrl( self, -1, style=wx.TE_MULTILINE|wx.MAXIMIZE )
-        text_control.SetEditable( False )
-        text_control.SetFont( wx.Font(wb_diff_frame.point_size, wx.DEFAULT,
-                                     wx.NORMAL, wx.NORMAL, False, wb_diff_frame.face) )
-        text_control.AppendText( text )
+        text_control = wx.stc.StyledTextCtrl( self, -1,
+                wx.DefaultPosition, wx.DefaultSize, wx.NO_BORDER )
+        text_control.StyleSetSpec( wx.stc.STC_STYLE_DEFAULT, 
+                "size:%d,face:%s,fore:#000000" % (wb_config.point_size, wb_config.face) )
+
+        text_control.SetReadOnly( False )
+        text_control.InsertText( 0, text )
+        text_control.SetReadOnly( True )
 
         self.CreateStatusBar()
         self.Show( True )
