@@ -89,6 +89,22 @@ def subversionDiffFiles(
     if mode == 'svn-diff' and (old_path_info.revision is None or new_path_info.revision is None):
         mode = 'built-in'
 
+    # Check for possible errors in advance to give the user a clear message.
+    for path_info in (old_path_info, new_path_info):
+        if( path_info.revision is None
+        or path_info.revision.kind == pysvn.opt_revision_kind.working ):
+            if not os.path.exists( path_info.path ):
+                app.log_error( '"%s" does not exist.' % path_info.path )
+                return
+
+            if os.path.isdir( path_info.path ):
+                app.log_error( '"%s" refers to a directory.' % path_info.path )
+                return
+
+            if not os.access( path_info.path, os.R_OK ):
+                app.log_error( '"%s" cannot be read.' % path_info.path )
+                return
+
     if mode == 'svn-diff':
         # svn will do all the work
         yield app.backgroundProcess
@@ -267,22 +283,25 @@ def __getFileContents( project_info, path_info ):
     if path_info.revision is None or path_info.revision.kind == pysvn.opt_revision_kind.working:
         all_content_lines = wb_read_file.readFileContentsAsUnicode( path_info.path ).split('\n')
 
-    elif path_info.revision.kind == pysvn.opt_revision_kind.base:
-        all_content_lines = project_info.client_bg.cat(
-                url_or_path=path_info.path,
-                revision=path_info.revision ).split('\n')
-
     else:
-        if path_info.peg_revision is not None:
-            all_content_lines = project_info.client_bg.cat(
-                url_or_path=path_info.peg_path,
-                revision=path_info.revision,
-                peg_revision=path_info.peg_revision ).split('\n')
+        if path_info.revision.kind == pysvn.opt_revision_kind.base:
+            all_contents = project_info.client_bg.cat(
+                url_or_path=path_info.path,
+                revision=path_info.revision )
 
         else:
-            all_content_lines = project_info.client_bg.cat(
-                url_or_path=path_info.path,
-                revision=path_info.revision ).split('\n')
+            if path_info.peg_revision is not None:
+                all_contents = project_info.client_bg.cat(
+                    url_or_path=path_info.peg_path,
+                    revision=path_info.revision,
+                    peg_revision=path_info.peg_revision )
+
+            else:
+                all_contents = project_info.client_bg.cat(
+                    url_or_path=path_info.path,
+                    revision=path_info.revision )
+
+        all_content_lines = wb_read_file.contentsAsUnicode( all_contents ).split( '\n' ) 
 
     return all_content_lines
 
