@@ -79,7 +79,7 @@ class LogEntry:
             assert( False )
             return False
 
-def getHistoryEntries( project_info, filename, limit, revision_end ):
+def getHistoryEntries( project_info, filename, limit, revision_end, include_tags ):
     all_history_entries = []
     # need the URL and repos_root_URL
     # [0] first entry [0][1] the info
@@ -118,22 +118,32 @@ def getHistoryEntries( project_info, filename, limit, revision_end ):
     oldest_rev = log.revision.number
 
     tags_url = project_info.getTagsUrl( info.URL )
-    if tags_url:
+    if include_tags and tags_url:
         try:
+            tag_info = project_info.client_bg.info2( tags_url, recurse=False )
+            tag_repos_prefix = tags_url[len(tag_info[0][1].repos_root_URL):]
+            all_tag_names = set()
+
             for log in project_info.client_bg.log( tags_url, discover_changed_paths=True ):
                 for changed_path in log.changed_paths:
-                    if changed_path.copyfrom_revision is not None:
-                        # only include if it has taged an item in the history
-                        if changed_path.copyfrom_revision.number > oldest_rev:
+                    if( changed_path.copyfrom_revision is not None
+                    # only include if it has taged an item in the history
+                    and changed_path.copyfrom_revision.number > oldest_rev ):
+                        tag_suffix = changed_path.path[len(tag_repos_prefix)+1:]
+                        tag_name = tag_suffix.split('/')[0]
+
+                        if tag_name not in all_tag_names:
                             all_history_entries.append(
                                 LogEntry(
                                     changed_path.copyfrom_revision.number,
                                     __findTaggedUrl( all_history_entries, changed_path.copyfrom_revision.number ),
                                     log.author,
                                     log.date,
-                                    'Tag ' + changed_path.path.split('/')[-1],
+                                    'Tag ' + tag_name,
                                     log.message,
                                     log.changed_paths) )
+
+                        all_tag_names.add( tag_name )
                         break
 
         except pysvn.ClientError, e:
@@ -153,35 +163,53 @@ def __findTaggedUrl( all_history_entries, tag_revnum ):
     # this cannot happen
     raise RuntimeError( '__findTaggedUrl failed to find tagged url' )
 
-class HistoryDialog(wx.Dialog):
-    def __init__( self, parent ):
+class LogHistoryDialog(wx.Dialog):
+    def __init__( self, app, parent ):
         wx.Dialog.__init__( self, parent, -1, 'Log History' )
 
+        p = app.prefs.getLogHistory()
+
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
+        is_show_all = p.default_mode == 'show_all'
+        is_show_limit = p.default_mode == 'show_limit'
+        is_show_since = p.default_mode == 'show_since'
+
         self.all_radio = wx.RadioButton( self, -1, 'Show all entries' )
-        self.all_radio.SetValue( True )
+        self.all_radio.SetValue( is_show_all )
+
         self.g_sizer.Add( self.all_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( (0,0), 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
         self.limit_radio = wx.RadioButton( self, -1, 'Show only:' )
-        self.limit_text = wx.TextCtrl( self, -1, '20', style=wx.TE_RIGHT )
-        self.limit_text.Enable( False )
+        self.limit_radio.SetValue( is_show_limit )
+        self.limit_text = wx.TextCtrl( self, -1, str(p.default_limit), style=wx.TE_RIGHT )
+        self.limit_text.Enable( is_show_limit )
+
         self.g_sizer.Add( self.limit_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.limit_text, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
         self.date = wx.DateTime_Now()
-        self.date.SubtractDS( wx.DateSpan( weeks=1 ) )
+        self.date.SubtractDS( wx.DateSpan( days=p.default_since_days_interval ) )
 
         self.since_radio = wx.RadioButton( self, -1, 'Show since:' )
+        self.since_radio.SetValue( is_show_since )
         self.since_date = wx.calendar.CalendarCtrl( self, -1,
                                 self.date,
                                 style=wx.calendar.CAL_MONDAY_FIRST )
-        self.since_date.Enable( False )
+        self.since_date.Enable( is_show_since )
+
         self.g_sizer.Add( self.since_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_TOP, 3 )
         self.g_sizer.Add( self.since_date, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
+        self.tags_label = wx.StaticText( self, -1, 'Include tags: ', style=wx.ALIGN_RIGHT)
+        self.tags_ctrl = wx.CheckBox( self, -1, 'Include tags in log history' )
+        self.tags_ctrl.SetValue( p.default_include_tags )
+
+        self.g_sizer.Add( self.tags_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.g_sizer.Add( self.tags_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
         self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
         self.button_ok.SetDefault()
         self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
@@ -261,6 +289,9 @@ class HistoryDialog(wx.Dialog):
         else:
             return pysvn.Revision( pysvn.opt_revision_kind.number, 0 )
 
+    def getIncludeTags( self ):
+        return self.tags_ctrl.GetValue()
+
 class HistoryFileFrame(wx.Frame):
     def __init__( self, app, project_info, filename, url, all_log_entries ):
         wx.Frame.__init__( self, None, -1, "History of %s" % filename, size=(700,500) )
