@@ -10,6 +10,7 @@
     wb_subversion_list_handler.py
 
 '''
+import types
 import pysvn
 import wx
 import wb_subversion_utils
@@ -24,7 +25,8 @@ class InfoDialog(wx.Dialog):
         self.addGroup( 'Entry' )
         self.addRow( 'Path:',path )
 
-        if type(info_entry_or_info2_list) == type([]):
+        #print 'info_entry_or_info2_list',info_entry_or_info2_list
+        if type(info_entry_or_info2_list) == types.ListType:
             self.initForInfo2( info_entry_or_info2_list[0][1] )
         else:
             self.initForInfo1( info_entry_or_info2_list )
@@ -145,7 +147,7 @@ class InfoDialog(wx.Dialog):
         elif wc_info['schedule'] == pysvn.wc_schedule.replace:
             self.addRow( 'Schedule:','replace' )
         else:
-            self.addRow( 'Schedule:', str(wc_info['schedule']))
+            self.addRow( 'Schedule:', unicode(wc_info['schedule']))
         if wc_info['copyfrom_url']:
             self.addRow( 'Copied From URL:', wc_info['copyfrom_url'] )
             if wc_info['copyfrom_rev'].number:
@@ -169,11 +171,14 @@ class InfoDialog(wx.Dialog):
 
     def addRow( self, label, value ):
         label_ctrl = wx.StaticText( self, -1, label, style=wx.ALIGN_RIGHT )
-        str_value = str(value)
+        str_value = unicode(value)
+
+        # cannot set the controls readonly as that prevent copy of the text
         if '\n' in str_value:
-            value_ctrl = wx.TextCtrl( self, -1, str(value), size=wx.Size( -1, 100 ), style=wx.TE_READONLY|wx.TE_MULTILINE )
+            value_ctrl = wx.TextCtrl( self, -1, unicode(value), size=wx.Size( -1, 100 ),
+                                        style=wx.TE_MULTILINE )
         else:
-            value_ctrl = wx.TextCtrl( self, -1, str(value), style=wx.TE_READONLY )
+            value_ctrl = wx.TextCtrl( self, -1, unicode(value) )
 
         self.g_sizer.Add( label_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( value_ctrl, 0, wx.EXPAND, 5 )
