@@ -23,18 +23,9 @@ import wb_subversion_properties_dialog
 import wb_subversion_utils
 import wb_subversion_checkin
 import wb_clipboard
+import wb_diff_frame
 
 class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHandlerCommon):
-    col_name = 'Name'
-    col_state = 'State'
-    col_date = 'Date'
-    col_revision = 'Rev'
-    col_author = 'Author'
-    col_type = 'Type'
-    col_size = 'Size'
-    col_mime_type = 'Mimetype'
-    col_eol_style = 'EOL'
-
     def __init__( self, app, list_panel, project_info ):
         wb_subversion_list_handler_common.SubversionListHandlerCommon.__init__( self, app, list_panel, project_info )
 
@@ -274,21 +265,21 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
             old_filename = self.getConflictOld( row )
             new_filename = self.getConflictNew( row )
             # qqq diff old_filename@None, new_filename@None
-            self.app.Diff( old_filename, old_filename, new_filename, new_filename )
+            self.app.diffFiles( old_filename, old_filename, new_filename, new_filename )
 
     def Cmd_File_DiffOldMine( self, all_rows ):
         for row in all_rows:
             old_filename = self.getConflictOld( row )
             mine_filename = self.getConflictMine( row )
             # qqq diff old_filename@None, mine_filename@None
-            self.app.Diff( old_filename, old_filename, mine_filename, mine_filename )
+            self.app.diffFiles( old_filename, old_filename, mine_filename, mine_filename )
 
     def Cmd_File_DiffMineNew( self, all_rows ):
         for row in all_rows:
             mine_filename = self.getConflictMine( row )
             new_filename = self.getConflictNew( row )
             # qqq diff mine_filename@None, new_filename@None
-            self.app.Diff( mine_filename, mine_filename, new_filename, new_filename )
+            self.app.diffFiles( mine_filename, mine_filename, new_filename, new_filename )
 
     # Cmd_File_History = from SubversionListHandlerCommon
     # Cmd_File_Info = from SubversionListHandlerCommon
@@ -313,14 +304,19 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
 
         if text_status == pysvn.wc_status_kind.added:
             # need to save and restore the props around the rename dance
-            _, prop_dict = self.project_info.client_fg.proplist( old_filename,
-                            revision=pysvn.Revision( pysvn.opt_revision_kind.working ) )[0]
+            all_prop_lists = self.project_info.client_fg.proplist( old_filename,
+                            revision=pysvn.Revision( pysvn.opt_revision_kind.working ) )
             self.project_info.client_fg.revert( old_filename )
             print 'Rename %s %s' % (old_filename, new_full_filename)
             os.rename( old_filename, new_full_filename )
             self.project_info.client_fg.add( new_full_filename )
-            for prop_name, prop_value in prop_dict.items():
-                self.project_info.client_fg.propset( prop_name, prop_value, new_full_filename )
+
+            # all_prop_lists is empty if there are no properties set
+            if len(all_prop_lists) > 0:
+                _, prop_dict = all_prop_lists[0]
+
+                for prop_name, prop_value in prop_dict.items():
+                    self.project_info.client_fg.propset( prop_name, prop_value, new_full_filename )
 
         elif( text_status == pysvn.wc_status_kind.modified
         or prop_status == pysvn.wc_status_kind.modified ):
