@@ -422,17 +422,21 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
     def __get_LockCommentColumn( self, status ):
         if status.repos_lock is not None:
-            comment = status.repos_lock['comment'].replace( '\n', ' ' )
-        else:
+            comment = status.repos_lock.comment.replace( '\n', ' ' )
+        elif status.entry is not None and status.entry.lock_comment is not None:
             comment = status.entry.lock_comment.replace( '\n', ' ' )
+        else:
+            comment = ''
         return comment
 
     def __get_LockOwnerColumn( self, status ):
         if status.repos_lock is not None:
-            comment = status.repos_lock['owner']
+            owner = status.repos_lock.owner
+        elif status.entry is not None and status.entry.lock_owner is not None:
+            owner = status.entry.lock_owner
         else:
-            comment = status.entry.lock_owner
-        return comment
+            owner = ''
+        return owner
 
     def getState( self, all_rows ):
         if len(all_rows) == 0:
@@ -783,7 +787,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         self.app.setAction( 'Ready' )
 
     def Cmd_File_History( self, all_rows ):
-        dialog = wb_subversion_history.HistoryDialog( self.app.frame.tree_panel.tree_ctrl )
+        dialog = wb_subversion_history.LogHistoryDialog( self.app, self.app.frame.tree_panel.tree_ctrl )
         result = dialog.ShowModal()
         if result != wx.ID_OK:
             return
@@ -799,7 +803,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                             self.project_info,
                             filename,
                             dialog.getLimit(),
-                            dialog.getRevisionEnd() )
+                            dialog.getRevisionEnd(),
+                            dialog.getIncludeTags() )
                 ok = True
             except pysvn.ClientError, e:
                 self.app.log_client_error( e )
@@ -1006,11 +1011,56 @@ class SortList:
 
 
         if field == SubversionListHandlerCommon.col_eol_style:
-            return self.project_info.getProperty( status.path, 'svn:eol-style' )
+            value = self.project_info.getProperty( status.path, 'svn:eol-style' )
+            if value in ['', None]:
+                if self.sort_data.getOrder() > 0:
+                    value = (1, u'')
+                else:
+                    value = (-1, u'')
+            else:
+                value = (0, value)
+
+            return value
 
         if field == SubversionListHandlerCommon.col_mime_type:
             return self.project_info.getProperty( status.path, 'svn:mime-type' )
 
+        if field == SubversionListHandlerCommon.col_lock_owner:
+            if status.repos_lock is not None:
+                value = status.repos_lock.owner
+            elif status.entry is not None:
+                value = status.entry.lock_owner
+            else:
+                value = u''
+
+            if value in ['', None]:
+                if self.sort_data.getOrder() > 0:
+                    value = (1, u'')
+                else:
+                    value = (-1, u'')
+            else:
+                value = (0, value)
+
+            return value
+
+        if field == SubversionListHandlerCommon.col_lock_comment:
+            if status.repos_lock is not None:
+                value = status.repos_lock.comment.replace( '\n', ' ' )
+            elif status.entry is not None and status.entry.lock_comment is not None:
+                value = status.entry.lock_comment.replace( '\n', ' ' )
+            else:
+                value = u''
+
+            if value in ['', None]:
+                if self.sort_data.getOrder() > 0:
+                    value = (1, u'')
+                else:
+                    value = (-1, u'')
+            else:
+                value = (0, value)
+
+            return value
+
         raise wb_exceptions.InternalError( 'SortList does not support field %s' % field )
 
 class SortListCtrl(SortList):
