@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -52,6 +52,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         self.files_properties = {}
 
         self.tags_url = None
+        self.branches_url = None
 
     def __repr__( self ):
         return '<svn.ProjectInfo wc_path=%r>' % self.wc_path
@@ -84,12 +85,31 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             self.client_bg.callback_ssl_server_trust_prompt = CallFunctionOnMainThread( self.app, self.getServerTrust )
 
         self.tags_url = kws.get( 'tags_url', '' )
+        self.branches_url = kws.get( 'branches_url', '' )
+
+        # default the tags and branches URLs
+        url_parts = self.url.split('/')
+        if self.tags_url == '' and 'trunk' in url_parts:
+            trunk_index = url_parts.index('trunk')
+            url_parts[ trunk_index ] = 'tags'
+            self.tags_url = '/'.join( url_parts[:trunk_index+1] )
+
+        url_parts = self.url.split('/')
+        if self.branches_url == '' and 'trunk' in url_parts:
+            trunk_index = url_parts.index('trunk')
+            url_parts[ trunk_index ] = 'branches'
+            self.branches_url = '/'.join( url_parts[:trunk_index+1] )
 
     def getTagsUrl( self, rel_url ):
         if self.parent is not None:
             return self.parent.getTagsUrl( rel_url )
         return self.expandedLabelUrl( self.tags_url, rel_url )
 
+    def getBranchesUrl( self, rel_url ):
+        if self.parent is not None:
+            return self.parent.getBranchesUrl( rel_url )
+        return self.expandedLabelUrl( self.branches_url, rel_url )
+
     def expandedLabelUrl( self, label_url, rel_url ):
         if label_url is '':
             return ''
@@ -161,9 +181,14 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         else:
             tags_url = ''
 
+        if get_option.has( 'branches_url' ):
+            branches_url = get_option.getstr( 'branches_url' )
+        else:
+            branches_url = ''
+
         # expand any ~/ or ~user/ in the path
         wc_path = os.path.expanduser( wc_path )
-        self.init( name, url=url, wc_path=wc_path, tags_url=tags_url )
+        self.init( name, url=url, wc_path=wc_path, tags_url=tags_url, branches_url=branches_url )
 
     def writePreferences( self, pref_dict ):
         # save state into a preference file
@@ -172,6 +197,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         pref_dict[ 'url' ] = self.url
         pref_dict[ 'wc_path' ] = self.wc_path
         pref_dict[ 'tags_url' ] = self.tags_url
+        pref_dict[ 'branches_url' ] = self.branches_url
 
     def isEqual( self, pi ):
         return (self.provider_name == pi.provider_name
