@@ -11,11 +11,7 @@
 
 '''
 import wx
-import sys
-import wb_images
-import time
-import pysvn
-
+import wb_config
 import wb_ids
 import wb_images
 import wb_exceptions
@@ -145,7 +141,7 @@ class ReportBranchChangesListHandler(wb_subversion_list_handler_common.Subversio
         if text_code == ' ' and prop_code != ' ':
             text_code = '_'
 
-        return '%s%s' % (text_code, prop_code)
+        return file.get('branch_text_states', '') + text_code + prop_code
 
     def setupColumnInfo( self ):
         self.column_info.setFrom( ['State','Name'], [5, 100] )
