@@ -40,6 +40,8 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         self.project_info = project_info
         self.app = app
 
+        self.__log_message = None
+
     def updateStatus( self ):
         self.project_info.updateStatus()
 
@@ -197,6 +199,47 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_item )
 
+    def Cmd_Dir_CreateBranch( self ):
+        # must return the generator
+        return self.__copyToHelper( self.project_info.getBranchesUrl, wb_dialogs.CreateBranch, 'Creating branch %s' )
+
+    def Cmd_Dir_CreateTag( self ):
+        # must return the generator
+        return self.__copyToHelper( self.project_info.getTagsUrl, wb_dialogs.CreateTag, 'Creating tag %s' )
+
+    def __getLogMessage( self ):
+        return True, self.__log_message
+
+    # generator function - needs to be pumped
+    def __copyToHelper( self, get_url_fn, dialog_class, status_title ):
+        info = self.project_info.client_bg.info2( self.project_info.wc_path, recurse=False )[0][1]
+        copy_from_url = info.URL
+        copy_to_root_url = get_url_fn( copy_from_url )
+
+        dialog = dialog_class( self.app.frame.tree_panel.tree_ctrl, copy_from_url, copy_to_root_url )
+        if dialog.ShowModal() != wx.ID_OK:
+            return
+
+        copy_to_leaf_url = dialog.getCopyToLeaf()
+        copy_to_url = '%s/%s' % (copy_to_root_url, copy_to_leaf_url)
+        self.__log_message = dialog.getLogMessage().encode( 'utf-8' )
+
+        print status_title % copy_to_url
+        self.app.setAction( status_title % copy_to_leaf_url )
+
+        yield self.app.backgroundProcess
+        self.project_info.client_bg.callback_get_log_message = self.__getLogMessage
+        try:
+            self.project_info.client_bg.copy( copy_from_url,copy_to_url )
+        except pysvn.ClientError, e:
+            self.app.log_client_error( e )
+
+        self.project_info.client_bg.callback_get_log_message = None
+        yield self.app.foregroundProcess
+
+        self.app.setAction( 'Ready' )
+        self.app.refreshFrame()
+
     def Cmd_Dir_EditCopy( self ):
         self.app.setPasteData( wb_clipboard.Clipboard( [self.project_info.wc_path], is_copy=True ) )
         print 'Copied folder %s to the Clipboard' % self.project_info.wc_path
@@ -383,7 +426,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
     def Cmd_Dir_History( self ):
         filename = self.project_info.wc_path
 
-        dialog = wb_subversion_history.HistoryDialog( self.app.frame.tree_panel.tree_ctrl )
+        dialog = wb_subversion_history.LogHistoryDialog( self.app, self.app.frame.tree_panel.tree_ctrl )
         result = dialog.ShowModal()
         if result != wx.ID_OK:
             return
@@ -399,7 +442,8 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                         self.project_info,
                         filename,
                         dialog.getLimit(),
-                        dialog.getRevisionEnd() )
+                        dialog.getRevisionEnd(),
+                        dialog.getIncludeTags() )
             ok = True
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
@@ -609,26 +653,82 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         is_branch = False
 
         yield self.app.backgroundProcess
-        
+
         try:
             log_entries = self.project_info.client_bg.log( self.project_info.url, discover_changed_paths=True )
             if log_entries[-1]['changed_paths'][0]['copyfrom_path'] is not None:
                 is_branch = True
-                all_files = self.project_info.client_bg.status( self.project_info.wc_path,
-                    recurse=True, get_all=True, ignore=True, update=False )
+                changed_states = {}
+                prefix_len = len( log_entries[-1]['changed_paths'][0]['path'] )
                 repos_root_url = self.project_info.client_bg.info2( self.project_info.wc_path )[0][1]['repos_root_URL']
-                changed_urls = []
-                for log_entry in log_entries:
-                    for changed_paths in log_entry['changed_paths']:
-                        url = repos_root_url + changed_paths['path']
-                        if not (url in changed_urls):
-                            changed_urls.append( url )
-                for status in all_files:
-                    if (status.entry is not None 
-                        and status.entry.kind == pysvn.node_kind.file
-                        and (status.text_status != pysvn.wc_status_kind.normal or 
-                             status.entry.url in changed_urls)):
-                        changed_files.append( status )
+                local_states = self.project_info.client_bg.status( self.project_info.wc_path, recurse=True,
+                                                                   get_all=True, ignore=True, update=False )
+                for log_entry in reversed(log_entries[:-1]):
+                    for changed_path in log_entry['changed_paths']:
+                        repository_path = changed_path['path']
+                        url = repos_root_url + repository_path
+
+                        local_path = self.project_info.wc_path + repository_path[prefix_len:].replace( '/', os.path.sep )
+                        if changed_states.has_key(local_path):
+                            branch_text_states = changed_states[local_path]['branch_text_states']
+                        else:
+                            branch_text_states = ''
+                        branch_text_states += changed_path['action'].lower()
+
+                        # Create a new status object from the log entry data.
+                        entry = pysvn.PysvnEntry(
+                                    {'checksum': ''
+                                    ,'commit_author': log_entry.author
+                                    ,'commit_revision': log_entry.revision
+                                    ,'commit_time': log_entry.date
+                                    ,'conflict_new': None
+                                    ,'conflict_old': None
+                                    ,'conflict_work': None
+                                    ,'copy_from_revision': pysvn.Revision( pysvn.opt_revision_kind.number, -1 )
+                                    ,'copy_from_url': None
+                                    ,'is_absent': 0
+                                    ,'is_copied': 0
+                                    ,'is_deleted': 0
+                                    ,'kind': pysvn.node_kind.file
+                                    ,'lock_comment': None
+                                    ,'lock_creation_date': 0.0
+                                    ,'lock_owner': None
+                                    ,'lock_token': None
+                                    ,'name': repository_path.split( '/' )[-1]
+                                    ,'properties_time': 0.0
+                                    ,'property_reject_file': None
+                                    ,'repos': repos_root_url
+                                    ,'revision': log_entry.revision
+                                    ,'schedule': pysvn.wc_schedule.normal
+                                    ,'text_time': 0.0
+                                    ,'url': url
+                                    ,'uuid': ''})
+                        status = pysvn.PysvnStatus(
+                                    {'entry': entry
+                                    ,'is_copied': 0
+                                    ,'is_locked': 0
+                                    ,'is_switched': 0
+                                    ,'is_versioned': 1
+                                    ,'path': local_path
+                                    ,'prop_status': pysvn.wc_status_kind.normal
+                                    ,'repos_lock': None
+                                    ,'repos_prop_status': pysvn.wc_status_kind.none
+                                    ,'repos_text_status': pysvn.wc_status_kind.none
+                                    ,'branch_text_states': branch_text_states
+                                    ,'text_status': pysvn.wc_status_kind.normal})
+                        changed_states[local_path] = status
+
+                for status in local_states:
+                    if( status.entry is not None
+                    and ((status.text_status not in (pysvn.wc_status_kind.normal, pysvn.wc_status_kind.none))
+                        or
+                        (status.prop_status not in (pysvn.wc_status_kind.normal, pysvn.wc_status_kind.none))) ):
+                        if changed_states.has_key( status.path ):
+                            status['branch_text_states'] = changed_states[status.path]['branch_text_states']
+                        changed_states[status.path] = status
+
+                changed_files = [changed_states[status] for status in changed_states]
+
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
