@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -40,7 +40,7 @@ pysvn.wc_status_kind.unversioned:   '?',
 wc_status_checkin_map = {
 pysvn.wc_status_kind.missing:       False,
 pysvn.wc_status_kind.added:         True,
-pysvn.wc_status_kind.conflicted:    False,
+pysvn.wc_status_kind.conflicted:    True,       # allow user to see the conflicted file
 pysvn.wc_status_kind.deleted:       True,
 pysvn.wc_status_kind.external:      False,
 pysvn.wc_status_kind.ignored:       False,
@@ -156,6 +156,9 @@ if hasattr( pysvn.wc_notify_action, 'failed_lock' ):
 #    format the concise status from file
 #
 def _status_format( file ):
+    if file.entry is None:
+        return ''
+
     text_code = wc_status_kind_map[ file.text_status ]
     prop_code = wc_status_kind_map[ file.prop_status ]
     if text_code == ' ' and prop_code != ' ':
