@@ -717,6 +717,12 @@ class WbTreePanel(wx.Panel):
 
         wb_shell_commands.FileBrowser( self.app, handler.getProjectInfo() )
 
+    def OnSpCreateBranch( self ):
+        return self.Sp_Dispatch( 'Cmd_Dir_CreateBranch' )
+
+    def OnSpCreateTag( self ):
+        return self.Sp_Dispatch( 'Cmd_Dir_CreateTag' )
+
     def OnSpEditCopy( self ):
         return self.Sp_Dispatch( 'Cmd_Dir_EditCopy' )
 
